# Generated by Django 3.1.13 on 2021-08-18 23:01

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('siteconfigs', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='siteconfigmodel',
            name='key',
            field=models.CharField(max_length=120, verbose_name='Key'),
        ),
        migrations.AddConstraint(
            model_name='siteconfigmodel',
            constraint=models.UniqueConstraint(fields=('key', 'site'), name='unique key per site'),
        ),
        migrations.DeleteModel(
            name='SiteConfigKeyModel',
        ),
    ]
